echo off
setlocal enableextensions
REM cd /d "%~dp0"
cd resources
:start
cls
echo BruControl Universal Interface Firmware Tool v43
echo ------------------------------------------------
echo 1. Firmware Installation (load BruControl firmware into an interface).
echo 2. Network Setup (configure an interface using Ethernet/Wi-Fi network for communication with BruControl).
echo 3. Exit this tool.
echo Which Function would you like to perform?
echo.
SET /p environment="Enter the appropriate number: "
IF /i "%environment%" == "1" GOTO selectinterface
IF /i "%environment%" == "2" GOTO setup
IF /i "%environment%" == "3" GOTO end
GOTO start

:selectinterface
cls
echo Which interface is firmware being installed?
echo 1. Arduino MEGA
echo 2. Arduino 101
echo 3. Arduino Due
echo 4. Arduino Zero
echo 5. Arduino UNO
echo 6. Adafruit Feather M0
echo 7. Arduino Primo
echo a. NodeMCU 1.0 (ESP8266)
echo b. Wemos D1 and Mini (ESP8266)
echo c. Sonoff TH10/16
echo d. Sonoff Dual
echo 0. Return to main menu
SET /p interface="Enter the appropriate number: "
IF /i "%interface%" == "1" GOTO installmega
IF /i "%interface%" == "2" GOTO install101
IF /i "%interface%" == "3" GOTO installdue
IF /i "%interface%" == "4" GOTO installzero
IF /i "%interface%" == "5" GOTO installuno
IF /i "%interface%" == "6" GOTO installfeatherM0
IF /i "%interface%" == "7" GOTO installprimo
IF /i "%interface%" == "a" GOTO installnodemcu
IF /i "%interface%" == "b" GOTO installwemosd1
IF /i "%interface%" == "c" GOTO installsonoffth
IF /i "%interface%" == "d" GOTO installsonoffdual
IF /i "%interface%" == "0" GOTO start
echo Invalid Response. Exiting.
GOTO end

:installmega
SET filetype=(*.MEGA.*.hex)
GOTO install
:install101
SET filetype=(*.101.*.bin)
GOTO install
:installdue
SET filetype=(*.Due.*.bin)
GOTO install
:installzero
SET filetype=(*.Zero.*.bin)
GOTO install
:installuno
SET filetype=(*.UNO.*.hex)
GOTO install
:installfeatherM0
SET filetype=(*.FeatherM0.*.bin)
GOTO install
:installprimo
SET filetype=(*.Primo.*.hex)
GOTO install
:installnodemcu
SET filetype=(*.NodeMCU.*.bin)
GOTO install
:installwemosd1
SET filetype=(*.WemosD1.*.bin)
GOTO install
:installsonoffth
SET filetype=(*.SonoffTH.*.bin)
GOTO install
:installsonoffdual
SET filetype=(*.SonoffDual.*.bin)
GOTO install

:install
cls
echo Firmware Install Steps:
echo - Make sure the interface board is plugged into one of the computer's USB ports.
echo - Here is the list of COM ports found available on this computer.
echo - Check the computer's Device Manager if the interface board's COM port is not listed here.
echo.
CALL :SHOWCOMS
echo.
IF "%interface%" == "6" echo - Double-click the reset button on the interface board so that the LED glows bight and dim.
IF "%interface%" == "6" echo - Re-check the COM port number in Device Manager as it may change.
SET /p com="- Enter the COM port number of interface board (number only): "
cls
echo - Review User Manual and 'Interface Wiring Map' for this interface to select appropriate firmware code.
echo - Firmware name is BruControl.version.interface_type.options.
echo.
SET index=1
SETLOCAL ENABLEDELAYEDEXPANSION
FOR %%f IN %filetype% DO (
   SET file!index!=%%f
   ECHO !index! - %%f
   SET /A index=!index!+1
)
SETLOCAL DISABLEDELAYEDEXPANSION
SET /P selection="- Which firmware to upload (select by number above):"
SET file%selection% >nul 2>&1
IF ERRORLEVEL 1 ( 
   goto start
)
CALL :RESOLVE %%file%selection%%%
pause
IF "%interface%" == "1" avrdude -Cavrdude.conf -v -patmega2560 -cwiring -PCOM%com% -b115200 -D -Uflash:w:%file_name%:i
IF "%interface%" == "2" arduino101load -dfu=0.9.0-arduino1 -bin=%file_name% -port=COM%com% -v -ble_fw_str="ATP1BLE00R-1631C4439" -ble_fw_pos=169984 -rtos_fw_str="" -rtos_fw_pos=0 -core=2.0.0
IF "%interface%" == "3" bossac.exe -i -d --port=COM%com% -U false -e -w -v -b %file_name% -R
IF "%interface%" == "4" bossac.exe -i -d --port=COM%com% -U false -e -w -v -b %file_name% -R
IF "%interface%" == "5" avrdude -Cavrdude.conf -v -patmega328p -carduino -PCOM%com% -b115200 -D -Uflash:w:%file_name%:i 
IF "%interface%" == "6" bossac.exe -i -d -U true -e -w -v %file_name% -R
IF "%interface%" == "7" openocd.exe -f arduino_primo.cfg -c "program %file_name% verify reset exit"
IF "%interface%" == "a" esptool.exe -vv -cd nodemcu -cb 115200 -cp COM%com% -ca 0x00000 -cf %file_name%
IF "%interface%" == "b" esptool.exe -vv -cd nodemcu -cb 115200 -cp COM%com% -ca 0x00000 -cf %file_name%
IF "%interface%" == "c" esptool.exe -vv -cd ck -cb 115200 -bm dio -cp COM%com% -ca 0x00000 -cf %file_name%
IF "%interface%" == "d" esptool.exe -vv -cd ck -cb 115200 -cp COM%com% -ca 0x00000 -cf %file_name%

echo.
echo *** CRITICAL STEP ***
echo Check output above to verify the firmware upload completed successfully above before continuing.
pause
goto start

:setup
cls
echo Interface Network Setup Steps
echo Reminder: Firmware for Serial/USB (S), Web Panel (P), or Yun Network (Y) connections DO NOT need network setup.
echo 1. Continue to Default Network Setup.
echo 2. Return to main menu.
SET /p environment="Enter the appropriate number: "
IF /i "%environment%" == "1" GOTO setup_cont
GOTO start
:setup_cont
echo - Make sure the interface board is plugged into one of the computer's USB ports.
echo - Here is the list of COM ports on this computer.
echo - Check the computer's Device Manager if the interface board's COM port is not listed here.
echo.
CALL :SHOWCOMS
echo.
SET /p com="Enter the COM port the interface board is plugged into, number only: "
cls
echo Interface Network Setup Steps, continued
echo - BruControl must not already be connected to the interface via network. Close the application if so.
echo - Once Termite opens, enter "%%0&15;" (without quotes) into the field at the bottom and press Enter.
echo - A 10 second countdown will begin. Enter y to initate setup, n to cancel and initialize with previous or defaults.
echo - Follow the prompts to set up the interface's network configuration.
echo - If unsure, use your router's IP address for Gateway (GW) and 255.255.255.0 for Subnet (SN).
echo - Close Termite when done.
pause
del "termite.ini" >nul 2>&1
@echo off
@echo [Settings]> termite.ini
@echo Port=COM%com%>> termite.ini
type termite.txt >> termite.ini
termite.exe
goto start

:SHOWCOMS
for /f "tokens=1* delims==" %%I in ('wmic path win32_pnpentity get caption /format:list ^| find "COM"') do (
    call :setCOM "%%~J"
)
set -COM

:setCOM <WMIC_output_line>
setlocal
set "str=%~1"
set "num=%str:*(COM=%"
set "num=%num:)=%"
set str=%str:(COM=&rem.%
endlocal & set "-COM%num% = %str%"


:RESOLVE
SET file_name=%1

:end